@@ -21,14 +21,15 @@ struct fileinfo
 	int  prio;
 } finfo;
 
-#define basename(x)	(strrchr((x),'/')+1) 
+#define basename(x)	((strrchr((x),'/')!=NULL)?strrchr((x),'/')+1:(x)) 
 #define S_IRWXUGO       (S_IRWXU|S_IRWXG|S_IRWXO)
 
-#define VERSION		"1.0"
-#define	MAXPATHLENGTH	4096
-#define BLOCK		4096
+#define VERSION			"0.2"
+#define	MAXPATHLENGTH		4096
+#define BLOCK			4096
+#define INITIALFINFOCOUNT	20480
 /* for the hash comparison
  * for no hash comparison #undef MD5SUM
  */
-#define MD5SUM 		"/usr/bin/md5sum"
-#define MATCHCNT	32
+#define MD5SUM 			"/usr/bin/md5sum"
+#define MATCHCNT		32
